@@ -352,6 +352,9 @@ class Client(object):
         log.warning(u'%s code: %s @%s' % (http_status,
                                           report_data.get('error_type'),
                                           url,))
+        if traceback:
+            log.error(report_data.get('error_type'))
+            log.error(traceback.plaintext)
         del traceback
         return True
 
@@ -413,9 +416,10 @@ class Client(object):
         report_data['report_details'][0]['slow_calls'] = []
         for record in records:
             # we don't need that and json will barf anyways
-            del record['ignore_in']
-            del record['parents']
-            r = getattr(record, 'errormator_data', record)
+            # but operate on copy
+            r = dict(getattr(record, 'errormator_data', record))
+            del r['ignore_in']
+            del r['parents']
             report_data['report_details'][0]['slow_calls'].append(r)
         with self.slow_report_queue_lock:
             self.slow_report_queue.append(report_data)
@@ -560,7 +564,7 @@ def get_config(config=None, path_to_config=None, section_name='errormator'):
     if path_to_config:
         config = {}
         if not os.path.exists(path_to_config):
-            log.warning("Couldn't locate %s " % path_to_config)
+            logging.warning("Couldn't locate %s " % path_to_config)
             return config
         with open(path_to_config) as f:
             parser = ConfigParser.SafeConfigParser()
@@ -568,7 +572,7 @@ def get_config(config=None, path_to_config=None, section_name='errormator'):
             try:
                 config = dict(parser.items(section_name))
             except ConfigParser.NoSectionError as exc:
-                log.warning('No section name called %s in file' % section_name)
+                logging.warning('No section name called %s in file' % section_name)
             return config
     return config or {}
 
@@ -582,7 +586,7 @@ def decorate(ini_file=None, register_timing=True):
         # this shuts down all errormator functionalities
         if not asbool(config.get('errormator', True)):
             return app
-        log.critical('ERRORMATOR MIDDLEWARE')
+        logging.critical('ERRORMATOR MIDDLEWARE')
         ini_path = os.environ.get('ERRORMATOR_INI',
                                   config.get('errormator.config_path',
                                              ini_file))
@@ -611,7 +615,7 @@ def make_errormator_middleware(app, global_config=None, **kw):
     config = get_config(config=config, path_to_config=ini_path)
     # this shuts down all errormator functionalities
     if not asbool(config.get('errormator', True)):
-        log.warning("ERRORMATOR_INI config variable is missing from"
+        logging.warning("ERRORMATOR_INI config variable is missing from"
                     "environment or errormator.config_path "
                     "not passed in app global config, "
                     "or errormator disabled in config")
